@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Client;
 use vars '$VERSION';
-$VERSION = '2.15';
+$VERSION = '2.16';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -57,8 +57,8 @@ sub compileClient(@)
           : @_%2==0 ? ({@_}, undef)
           : error __x"client `{name}' called with odd length parameter list"
               , name => $name;
-        my ($req, $mtom) = $encode->($data, $charset);
 
+        my ($req, $mtom) = $encode->($data, $charset);
         my %trace;
         my $ans   = $transport->($req, \%trace, $mtom);
 
@@ -69,10 +69,9 @@ sub compileClient(@)
         $trace{encode_elapse} = $trace{transport_start} - $start;
 
         if(UNIVERSAL::isa($ans, 'XML::LibXML::Node'))
-#       {   $ans = $decode->($ans);
-{   $ans = try { $decode->($ans) };
-$trace{decode_errors} = $@ if $@;
-warn $@ if $@;
+        {   $ans = try { $decode->($ans) };
+            $trace{decode_errors} = $@ if $@;
+
             my $end = time;
             $trace{decode_elapse} = $end - $trace{transport_end};
             $trace{elapse} = $end - $start;
